Module lcm
use_
arithmetic
0.0.6
Module lcm
Module Items
Functions
In crate use_
arithmetic
use_arithmetic
Module
lcm
Functions

checked_
lcm
Computes the least common multiple of two unsigned integers.
lcm
Computes the least common multiple of two unsigned integers.